@@ -16,17 +16,17 @@ int main(int argc, char** argv)
   primesieve_iterator it;
   primesieve_init(&it);
 
-  /* indicate exact bounds to improve performance */
-  primesieve_skipto(&it, 0, limit);
+  /* Indicate exact bounds to improve performance */
+  primesieve_jump_to(&it, 0, limit);
 
   uint64_t sum = 0;
   uint64_t prime = 0;
 
-  /* iterate over the primes below 10^9 */
+  /* Iterate over the primes <= 10^9 */
   while ((prime = primesieve_next_prime(&it)) <= limit)
     sum += prime;
 
-  printf("Sum of the primes <= %" PRIu64 " = %" PRIu64 "\n", limit, sum);
+  printf("Sum of the primes <= %" PRIu64 ": %" PRIu64 "\n", limit, sum);
 
   primesieve_free_iterator(&it);
 
