@@ -1,18 +1,19 @@
 ///
 /// @file  nthPrime.cpp
 ///
-/// Copyright (C) 2024 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2025 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
 ///
 
+#include "PrimeSieveClass.hpp"
+#include "RiemannR.hpp"
+
 #include <primesieve/iterator.hpp>
-#include <primesieve/PrimeSieve.hpp>
 #include <primesieve/macros.hpp>
 #include <primesieve/pmath.hpp>
 #include <primesieve/primesieve_error.hpp>
-#include <primesieve/RiemannR.hpp>
 
 #include <stdint.h>
 #include <algorithm>
